==> knowledgeroot_0.9.7.3.orig.tar.gz: knowledgeroot-0.9.7.3/system/tinymce/jscripts/tiny_mce/plugins/ibrowser/config.php <==
<?php
// ================================================
// tinymce PHP WYSIWYG editor control
// ================================================
// Configuration file
// ================================================
// Developed: j-cons.com, mail@j-cons.com
// Copyright: j-cons (c)2004 All rights reserved.
// ------------------------------------------------
//                                   www.j-cons.com
// ================================================
// v.1.0, 2004-10-04
// ================================================

// load in the knowledgeroot configuration file
require_once("../../../../../../config/config.inc.php");

// directory where tinymce files are located
$tinyMCE_dir = 'system/tinymce/';
// base url for images
$tinyMCE_base_url = '';

if (!ereg('/$', $HTTP_SERVER_VARS['DOCUMENT_ROOT']))
  $tinyMCE_root = $HTTP_SERVER_VARS['DOCUMENT_ROOT'].$tinyMCE_dir;
else
  $tinyMCE_root = $HTTP_SERVER_VARS['DOCUMENT_ROOT'].substr($tinyMCE_dir,1,strlen($tinyMCE_dir)-1);

// Path to upload files relative to the document root.
$serverBasePath = substr( $_SERVER['PHP_SELF'], 0, strpos( $_SERVER['PHP_SELF'], "system/tinymce" ) );

// image library related config

// allowed extentions for uploaded image files
$tinyMCE_valid_imgs = array('gif', 'jpg', 'jpeg', 'png');

// allow upload in image library
$tinyMCE_upload_allowed = true;

// allow delete in image library
$tinyMCE_img_delete_allowed = true;

// image libraries
$tinyMCE_imglibs = array(
 array(
   'value'   => $serverBasePath . $CONFIG['knowledgeroot']['uploadfolder'],
   'text'    => 'Images',
 ),
 array(
    'value'   => $serverBasePath . $CONFIG['knowledgeroot']['uploadfolder'] . 'Image/',
    'text'    => 'FCKEditor Images',
  ),
);
// file to include in img_library.php (useful for setting $tinyMCE_imglibs dynamically
// $tinyMCE_imglib_include = '';
?>

==> knowledgeroot_0.9.8.5.1.orig.tar.gz: knowledgeroot-0.9.8.5.1/system/tinymce/jscripts/tiny_mce/plugins/ibrowser/config.php <==
<?php
// ================================================
// tinymce PHP WYSIWYG editor control
// ================================================
// Configuration file
// ================================================
// Developed: j-cons.com, mail@j-cons.com
// Copyright: j-cons (c)2004 All rights reserved.
// ------------------------------------------------
//                                   www.j-cons.com
// ================================================
// v.1.0, 2004-10-04
// ================================================

// load in the knowledgeroot configuration file
require_once("../../../../../../config/config.inc.php");
$CONFIG['include_prefix'] = "../../../../../../";
require_once("../../../../../../include/init.php");
$CONFIG = $CLASS['vars'];

// directory where tinymce files are located
$tinyMCE_dir = 'system/tinymce/';
// base url for images
$tinyMCE_base_url = '';

if (!ereg('/$', $HTTP_SERVER_VARS['DOCUMENT_ROOT']))
  $tinyMCE_root = $HTTP_SERVER_VARS['DOCUMENT_ROOT'].$tinyMCE_dir;
else
  $tinyMCE_root = $HTTP_SERVER_VARS['DOCUMENT_ROOT'].substr($tinyMCE_dir,1,strlen($tinyMCE_dir)-1);

// Path to upload files relative to the document root.
$serverBasePath = substr( $_SERVER['PHP_SELF'], 0, strpos( $_SERVER['PHP_SELF'], "system/tinymce" ) );

// image library related config

// allowed extentions for uploaded image files
$tinyMCE_valid_imgs = array('gif', 'jpg', 'jpeg', 'png');

// allow upload in image library
$tinyMCE_upload_allowed = true;

// allow delete in image library
$tinyMCE_img_delete_allowed = true;

// image libraries
$tinyMCE_imglibs = array(
 array(
   'value'   => $serverBasePath . $CONFIG['knowledgeroot']['uploadfolder'],
   'text'    => 'Images',
 ),
 array(
    'value'   => $serverBasePath . $CONFIG['knowledgeroot']['uploadfolder'] . 'Image/',
    'text'    => 'FCKEditor Images',
  ),
);
// file to include in img_library.php (useful for setting $tinyMCE_imglibs dynamically
// $tinyMCE_imglib_include = '';
?>
